﻿#
# Záloha databáze lokálního registru BikeGuard
#
# Pro spouštění tohoto skriptu je nutné nastavit politiku povolující jeho spuštění.
#
# Přes nabídku "Start" spustíte program "Windows PowerShell" jako administrátor a v něm příkaz:
# Set-ExecutionPolicy RemoteSigned
#
#
# V plánovači úloh se poté do akce přidá spouštění programu ve tvaru:
# powershell.exe -file "c:\cesta\ke-skriptu\backup.ps1"


# Seznam změn
#######################################################
# 24.4.2016 v. 2
# Opraven připojovací řetězec na lokální databázi - nastavení max. velikosti
#
# 14.4.2016 v. 1
# Vytvoření tohoto skriptu

$scriptPath = split-path -parent $MyInvocation.MyCommand.Definition

################  KONFIGURACE  #################

# cesta do adresáøa kam se bude záloha ukládat
$backupDest = "$($env:APPDATA)\BikeGuard"             # toto nastavení bude ukládat do uživatelského profilu "C:\Users\{JMENO-UZIVATELE}\AppData\Roaming\BikeGuard"
# $backupDest = 'D:\muj-adresar\moje-cesta'           # cestu je také možno zadat tímto způsobem

# cesta k souboru s databází lokálního registru
$source = "$($scriptPath)"                            # pokud je zadáno takto, tak předpokládá, že skript je umístěn v adresáři s webovou aplikací BikeGuard
# $source = 'C:\InetPub\BikeGuard'                    # zde je cesta zadána přímo, skript může být umístěn kdekoliv na disku

################################################

Clear-Host

$sourceDb = Join-Path $source '\App_Data\bikes.sdf'

Set-Location $scriptPath

$Logfile = "$scriptPath\zaloha.log"
Function Write-Log
{
   Param ([string]$logstring)
   [datetime]$dt = Get-Date
   Add-content $Logfile -value "$dt`t$logstring"
   Write-Host $logstring
}


Write-Log 'Start...'
Write-Log "Backup destination: $backupDest"
Write-Log "Source: $source"

if (!(Test-Path -Path $backupDest)) {
    New-Item -ItemType Directory -Path $backupDest
    Write-Log "Create directory: $backupDest"
}

$appOnline = Join-Path $scriptPath '!app_offline.htm'
$appOffline  = Join-Path $scriptPath 'app_offline.htm'
if (Test-Path $appOnline) {
    Rename-Item $appOnline $appOffline -Force
}

$destDb = Join-Path $backupDest 'bikes.sdf'
Copy-Item $sourceDb $destDb -Force

Rename-Item $appOffline $appOnline -Force

#$Host.UI.RawUI.BufferSize = New-Object Management.Automation.Host.Size (500, 25)
 
$binpath = Join-Path $source 'bin\System.Data.SqlServerCe.dll'
[Reflection.Assembly]::LoadFile($binpath)
$connString = "Data Source=$($sourceDb);Max Database Size=4000"
$cn = new-object 'System.Data.SqlServerCe.SqlCeConnection' $connString
$cmd = new-object 'System.Data.SqlServerCe.SqlCeCommand'
$cmd.CommandType = [System.Data.CommandType]'Text'
$cmd.Connection = $cn

$dateBackup = [DateTime]::Now.ToString('dd.MM.yyyy HH:mm')
$sql = "INSERT INTO settings([key],[value]) VALUES('last_backup_date', '$($dateBackup)')"

$cn.Open()
$cmd.CommandText = "SELECT [value] FROM settings WHERE [key] = 'last_backup_date'"
$r = $cmd.ExecuteReader()
if ($r.Read()) {    
    $last = $r.GetString(0)
    Write-Log "Previous backup date: $last"
    $sql = "UPDATE settings SET [value] = '$($dateBackup)' WHERE [key] = 'last_backup_date'"
}
$r.Close()

$cmd.CommandText = $sql
$cmd.ExecuteNonQuery()

$cn.Close()

Write-Log 'Finnish.'
